push = require('push.push')

VIRTUAL_WIDTH, VIRTUAL_HEIGHT = 640, 430
TILE_WIDTH, TILE_HEIGHT = 32, 32

local function _GenerateFrames(atlas, frameWidth, frameHeight)
    local tiles_across = atlas:getWidth() / frameWidth
    local tiles_down = atlas:getHeight() / frameHeight
    local sprite_sheet = {}
    local frame_num = 0
    for tileY = 0, tiles_down - 1 do
        for tileX = 0, tiles_across - 1 do
            frame_num = frame_num + 1
            sprite_sheet[frame_num] = love.graphics.newQuad(tileX * frameWidth, tileY* frameHeight, frameWidth, frameHeight, atlas:getDimensions())
        end
    end
    return sprite_sheet
end

local _Textures = {
    ['food'] = love.graphics.newImage('images/food.png'),
}

local _frames = {}

local _Fonts = {
    ['huge'] = love.graphics.newFont('fonts/waltographUI.ttf', 72),
    ['large'] = love.graphics.newFont('fonts/waltographUI.ttf', 48),
    ['medium'] = love.graphics.newFont('fonts/waltographUI.ttf', 24),
    ['small'] = love.graphics.newFont('fonts/waltographUI.ttf', 18),
}

function love.load()
    local window_width, window_height = love.window.getDesktopDimensions()
    push:setupScreen(VIRTUAL_WIDTH, VIRTUAL_HEIGHT, window_width, window_height, {fullscreen = true, resizeable = true})
    push:setBorderColor(0,0,1,1)
    for k,t in pairs(_Textures) do
        _frames[k] = _GenerateFrames(t, TILE_WIDTH, TILE_HEIGHT)
    end
    smallMessage = love.graphics.newText(_Fonts['small'], 'Small Text')
    largeMessage = love.graphics.newText(_Fonts['large'], 'Large Text')
end

function love.draw()
    push:start()
    love.graphics.setColor(0.2, 0.2, 0.2, 1)
    love.graphics.rectangle('fill', 0, 0, VIRTUAL_WIDTH, VIRTUAL_HEIGHT)
    love.graphics.setColor(1, 1, 1, 1)
    local x_padding, y_padding = TILE_WIDTH, TILE_HEIGHT
    local food_x = VIRTUAL_WIDTH - x_padding - TILE_WIDTH
    local food_y = VIRTUAL_HEIGHT - y_padding - TILE_HEIGHT
    local nrows = 1
    local maxrows = 2
    -- draw a couple rows of sprites starting at the lower-right corner
    for i, f in ipairs(_frames['food']) do
        love.graphics.draw(_Textures['food'], f, food_x, food_y)
        food_x = food_x - x_padding - TILE_WIDTH
        if food_x < 0 + x_padding then
            nrows = nrows + 1
            if nrows > maxrows then break end
            food_x = VIRTUAL_WIDTH - x_padding - TILE_WIDTH
            food_y = food_y - y_padding - TILE_HEIGHT
        end
    end
    local text_x = 0 + x_padding
    local text_y = food_y - y_padding - smallMessage:getHeight()
    love.graphics.draw(smallMessage, text_x, text_y)
    text_y = text_y - y_padding - largeMessage:getHeight()
    love.graphics.draw(largeMessage, text_x, text_y)
    push:finish()
    local realWidth, realHeight, _ = love.window.getMode()
    love.graphics.setFont(_Fonts['large'])
    love.graphics.printf('Large Text outside push', 0, 0, realWidth, 'center')
    love.graphics.setFont(_Fonts['huge'])
    love.graphics.printf('Huge Text outside push', 0, 64, realWidth, 'center')
    love.graphics.setFont(_Fonts['small'])
    love.graphics.printf('Small Text outside push', 0, 144, realWidth, 'center')
end

function love.keypressed(key)
    if key == 'escape' then
        love.event.quit()
    end
end

function love.resize(w, h)
    push:resize(w, h)
end
